@@ -1,3 +1,4 @@
+import curlify
 from qtcurate.config import BASE_URL
 from time import sleep
 import requests
@@ -5,11 +6,13 @@ import re
 import json
 from typing import Dict, List
 import os.path
+from qtcurate.qt import Qt
 from qtcurate.exceptions import QtFileTypeError, QtArgumentError, QtConnectionError, QtRestApiError, QtDataProcessError
 from qtcurate.data_types import SearchMode, DictionaryType, AnalyzeMode
 
 
 tag_files = "files"
+num_workers = "numWorkers"
 tag_urls = "urls"
 tag_title = "title"
 tag_stitle = "stitle"
@@ -30,54 +33,21 @@ tag_sources = "source"
 
 
 class DataProcess:
-    def __init__(self, api_key: str, environment: str = ""):
+    def __init__(self, environment: str = ""):
         self.session = requests.Session()
-        self.headers = {"X-API-Key": api_key}
+        self.headers = {"X-API-Key": Qt.api_key}
         self.temp_dict = dict()
         self.temp_dict[tag_exclude_utt] = True
         self.temp_dict[tag_sort_by_position] = False
+        self.temp_dict[num_workers] = 4
         self.temp_dict[tag_search_dict] = []
         self.index = None
+        self.uuid = None
+        self.id = None
         if environment != "":
             environment = f"{environment}."
         self.url = f"http://{environment}{BASE_URL}"
 
-    def connect(self, method: str, uri: str, data: Dict = None) -> Dict:
-        if method.lower() == 'get':
-            try:
-                res = self.session.get(uri, headers=self.headers)
-
-            except requests.exceptions.RequestException as e:
-                raise QtConnectionError(f"Connection error: {e}")
-            if res.status_code not in [200, 201, 202]:
-                raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
-                                     f"HTTP status code: {res.status_code}. Server message: {res.json()}")
-        elif method.lower() == "delete":
-            try:
-                res = self.session.delete(uri, headers=self.headers)
-            except requests.exceptions.RequestException as e:
-                raise QtConnectionError(f"Connection error: {e}")
-            if res.status_code not in [200, 201, 202]:
-                raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
-                                     f"HTTP status code: {res.status_code}. Server message: {res.json()}")
-        elif method.lower() == "post":
-            try:
-                res = self.session.post(uri, headers=self.headers, data=json.dumps(data))
-            except requests.exceptions.RequestException as e:
-                raise QtConnectionError(f"Connection error: {e}")
-            if res.status_code not in [200, 201, 202]:
-                raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
-                                     f"HTTP status code: {res.status_code}. Server message: {res.json()}")
-        elif method.lower() == "put":
-            try:
-                res = self.session.put(uri, headers=self.headers, data=json.dumps(data))
-            except requests.exceptions.RequestException as e:
-                raise QtConnectionError(f"Connection error: {e}")
-            if res.status_code not in [200, 201, 202]:
-                raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
-                                     f"HTTP status code: {res.status_code}. Server message: {res.json()}")
-
-        return res
 
     def __repr__(self):
         return f"{self.temp_dict}"
@@ -85,6 +55,9 @@ class DataProcess:
     def get_id(self):
         return self.index
 
+    def get_uuid(self):
+        return self.uuid
+
     def title(self, title_name: str) -> None:
         """Create title for mining data"""
 
@@ -125,6 +98,12 @@ class DataProcess:
         else:
             raise QtArgumentError("Argument type error: Boolean is expected as exclude utt without entities")
 
+    def set_workers(self, value: int) -> None:
+        if isinstance(value, int):
+            self.temp_dict[num_workers] = value
+        else:
+            raise QtArgumentError("Argument type error: Integer is expected as num_workers")
+
     def files(self, list_of_files: list) -> None:
         """Create a list of existing files"""
 
@@ -236,12 +215,12 @@ class DataProcess:
         self.temp_dict.pop(tag_urls, None)
         self.temp_dict.pop(tag_title, None)
         self.temp_dict[tag_exclude_utt] = True
+        self.temp_dict[num_workers] = 4
         self.temp_dict.pop(tag_search_dict, None)
         self.index = None
 
     def upload(self, file: str) -> Dict:
         """Upload files for data mining"""
-
         if not isinstance(file, str):
             raise QtArgumentError("Argument type error: String is expected as file path")
 
@@ -252,8 +231,14 @@ class DataProcess:
             raise QtArgumentError(f"Argument error: File {file} does not exist")
         files = {'file': open(file, 'rb')}
 
-        res = self.connect("post", f"{self.url}search/file", files)
-        self.index = res.json()['index']
+        try:
+            res = self.session.post(f"{self.url}search/file", headers=self.headers, files=files)
+        except requests.exceptions.RequestException as e:
+            raise QtConnectionError(f"Connection error: {e}")
+        if res.status_code not in [200, 201, 202]:
+            raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
+                                 f"HTTP status code: {res.status_code}. Server message: {res.json()}")
+        self.uuid = res.json()['uuid']
         return res.json()
 
     def create(self) -> Dict:
@@ -283,7 +268,14 @@ class DataProcess:
             data[tag_search_dict] = self.temp_dict[tag_search_dict]
         if tag_title in self.temp_dict:
             data[tag_title] = self.temp_dict[tag_title]
-        res = self.connect("post", f"{self.url}search/new", data)
+        try:
+            res = self.session.post(f"{self.url}search/new", headers=self.headers, data=json.dumps(data))
+        except requests.exceptions.RequestException as e:
+            raise QtConnectionError(f"Connection error: {e}")
+        if res.status_code not in [200, 201, 202]:
+            raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
+                                 f"HTTP status code: {res.status_code}. Server message: {res.json()}")
+
         self.index = res.json()['index']
         del self.headers['Content-Type']
 
@@ -295,7 +287,13 @@ class DataProcess:
         self.headers["Content-Type"] = "application/json"
         if not isinstance(dp_id, str):
             raise QtArgumentError("Argument type error: String is expected as dp_id")
-        res = self.connect("get", f"{self.url}search/{dp_id}")
+        try:
+            res = self.session.get(f"{self.url}search/{dp_id}", headers=self.headers)
+        except requests.exceptions.RequestException as e:
+            raise QtConnectionError(f"Connection error: {e}")
+        if res.status_code not in [200, 201, 202]:
+            raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
+                                 f"HTTP status code: {res.status_code}. Server message: {res.json()}")
         del self.headers['Content-Type']
 
         return res.json()
@@ -311,9 +309,15 @@ class DataProcess:
         else:
             self.clear()
             data = {tag_files: update_files}
-        res = self.connect("post", f"{self.url}search/update/{dp_id}", data)
-        del self.headers['Content-Type']
+        try:
+            res = self.session.post(f"{self.url}search/update/{dp_id}", headers=self.headers, data=json.dumps(data))
+        except requests.exceptions.RequestException as e:
+            raise QtConnectionError(f"Connection error: {e}")
+        if res.status_code not in [200, 201, 202]:
+            raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
+                                 f"HTTP status code: {res.status_code}. Server message: {res.json()}")
 
+        del self.headers['Content-Type']
 
         return res.json()
 
@@ -328,7 +332,13 @@ class DataProcess:
         else:
             self.clear()
             data = {tag_files: update_files}
-        res = self.connect("post", f"{self.url}search/new/{dp_id}", data)
+        try:
+            res = self.session.post(f"{self.url}search/new/{dp_id}", headers=self.headers, data=json.dumps(data))
+        except requests.exceptions.RequestException as e:
+            raise QtConnectionError(f"Connection error: {e}")
+        if res.status_code not in [200, 201, 202]:
+            raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
+                                 f"HTTP status code: {res.status_code}. Server message: {res.json()}")
 
         self.index = res.json()['index']
         del self.headers['Content-Type']
@@ -340,7 +350,13 @@ class DataProcess:
 
         if not isinstance(dp_id, str):
             raise QtArgumentError("Argument type error: String is expected as dp_id")
-        res = self.connect("delete", f"{self.url}search/{dp_id}")
+        try:
+            res = self.session.delete(f"{self.url}search/{dp_id}", headers=self.headers)
+        except requests.exceptions.RequestException as e:
+            raise QtConnectionError(f"Connection error: {e}")
+        if res.status_code not in [200, 201, 202]:
+            raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
+                                 f"HTTP status code: {res.status_code}. Server message: {res.json()}")
 
         return res.ok
 
@@ -353,7 +369,13 @@ class DataProcess:
                 url_path = f"{url_path}/{dp_id}"
             else:
                 raise QtArgumentError("Expected string")
-        res = self.connect("get", f"{self.url}search/{url_path}")
+        try:
+            res = self.session.get(f"{self.url}search/{url_path}", headers=self.headers)
+        except requests.exceptions.RequestException as e:
+            raise QtConnectionError(f"Connection error: {e}")
+        if res.status_code not in [200, 201, 202]:
+            raise QtRestApiError(f"HTTP error: Full authentication is required to access this resource. "
+                                 f"HTTP status code: {res.status_code}. Server message: {res.json()}")
 
         return res.json()
 
